@@ -32,10 +32,8 @@ text editor instances.
 @contact: mystilleef@gmail.com
 """
 
-from pygtk import require
-from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, TYPE_OBJECT
-from gobject import TYPE_STRING, SIGNAL_RUN_FIRST
-require("2.0")
+from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, TYPE_OBJECT, TYPE_PYOBJECT
+from gobject import SIGNAL_RUN_FIRST, SIGNAL_ACTION, SIGNAL_RUN_CLEANUP, SIGNAL_NO_RECURSE
 
 class Editor(GObject):
 	"""
@@ -46,36 +44,36 @@ class Editor(GObject):
 	"""
 
 	__gsignals__ = {
-		"checking-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"loading-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"loaded-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"reload-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"load-error": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"enable-readonly": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"disable-readonly": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"saving-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"saved-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"save-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"save-error": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
+		"checking-document": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"loading-document": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"loaded-document": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"reload-document": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"load-error": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"enable-readonly": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"disable-readonly": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"saving-document": (SIGNAL_ACTION|SIGNAL_RUN_FIRST|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"saved-document": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"save-document": (SIGNAL_ACTION|SIGNAL_RUN_FIRST|SIGNAL_NO_RECURSE, TYPE_NONE, ()),
+		"save-error": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_PYOBJECT,)),
 		"gui-created": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"show-dialog": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
-		"hide-dialog": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
-		"renamed-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"modified-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"close-document": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"close-document-no-save": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"created-widgets": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"enable-fullscreen": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"disable-fullscreen": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"not-yet-implemented": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"show-bar": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
-		"hide-bar": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_OBJECT,)),
-		"updated-template-database": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"cursor-moved": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"initialized-trigger-manager": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"initialized-attributes": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
-		"rename-document": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_STRING,)),
-		"buffer-created": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"show-dialog": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_OBJECT,)),
+		"hide-dialog": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_OBJECT,)),
+		"renamed-document": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"modified-document": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, ()),
+		"close-document": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"close-document-no-save": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"created-widgets": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"enable-fullscreen": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"disable-fullscreen": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"not-yet-implemented": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"show-bar": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_OBJECT,)),
+		"hide-bar": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_OBJECT,)),
+		"updated-template-database": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, ()),
+		"cursor-moved": (SIGNAL_ACTION|SIGNAL_RUN_CLEANUP|SIGNAL_NO_RECURSE, TYPE_NONE, ()),
+		"initialized-trigger-manager": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"initialized-attributes": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
+		"rename-document": (SIGNAL_ACTION|SIGNAL_RUN_FIRST|SIGNAL_NO_RECURSE, TYPE_NONE, (TYPE_PYOBJECT,)),
+		"buffer-created": (SIGNAL_ACTION|SIGNAL_RUN_LAST, TYPE_NONE, ()),
 	}
 
 	def __init__(self, manager, file_uri=None, encoding=None):
@@ -91,7 +89,7 @@ class Editor(GObject):
 		@param file_uri: A file to open.
 		@param type: A String object.
 		"""
-		self.__gobject_init__() # default constructor using our new GType
+		GObject.__init__(self)
 		self.__signal_id_1 = self.connect("initialized-attributes", self.__initialized_attributes_cb)
 		self.__signal_id_2 = self.connect("created-widgets", self.__created_widgets_cb)
 		self.__signal_id_3 = self.connect_after("gui-created", self.__gui_created_after_cb)
@@ -106,8 +104,9 @@ class Editor(GObject):
 		self.__signal_id_12 = self.connect("rename-document", self.__rename_document_cb)
 		self.__signal_id_13 = self.connect_after("created-widgets", self.__created_widgets_after_cb)
 		self.__signal_id_14 = self.connect_after("reload-document", self.__reload_document_cb)
-		from gobject import idle_add
-		idle_add(self.__init_attributes, manager, file_uri, encoding)
+		from gobject import idle_add, PRIORITY_HIGH, PRIORITY_LOW
+		idle_add(self.__init_attributes, manager, file_uri, encoding, priority=PRIORITY_HIGH)
+		idle_add(self.__precompile_methods, priority=PRIORITY_LOW)
 
 ########################################################################
 #
@@ -332,9 +331,13 @@ class Editor(GObject):
 		return translators
 
 	def __get_copyrights(self):
-		from infor import copyrights
+		from info import copyrights
 		return copyrights
 
+	def __get_license(self):
+		from license import license_string
+		return license_string
+
 ########################################################################
 #
 #					Public API Properties
@@ -401,6 +404,7 @@ class Editor(GObject):
 	website = property(__get_website)
 	translators = property(__get_translators)
 	copyrights = property(__get_copyrights)
+	license = property(__get_license)
 
 ########################################################################
 #
@@ -443,6 +447,9 @@ class Editor(GObject):
 		self.__uri = make_uri_from_shell_arg(newfile)
 		return
 
+	def get_encoding_manager(self):
+		return self.__encoding_manager
+
 	def register_termination_id(self):
 		"""
 		Register a unique identification with the text editor.
@@ -486,6 +493,12 @@ class Editor(GObject):
 			timeout_add(100, self.__destroy)
 		return
 
+	def block_response(self):
+		return self.__instance_manager.block_response()
+
+	def unblock_response(self):
+		return self.__instance_manager.unblock_response()
+
 	def register_object(self):
 		return self.register_termination_id()
 
@@ -496,6 +509,11 @@ class Editor(GObject):
 		self.__trigger_manager.trigger(string)
 		return
 
+	def create_trigger(self, name, accelerator=None, description=None, error=True, removable=True):
+		from Trigger import Trigger
+		trigger = Trigger(name, accelerator, description, error, removable)
+		return trigger
+
 	def add_trigger(self, trigger):
 		self.__trigger_manager.add_trigger(trigger)
 		return
@@ -528,6 +546,38 @@ class Editor(GObject):
 		self.__store.remove_object(name, store_id)
 		return
 
+	def add_global_object(self, name, instance):
+		return self.__instance_manager.add_object(name, instance)
+
+	def remove_global_object(self, name, object_id):
+		return self.__instance_manager.remove_object(name, object_id)
+
+	def get_global_object(self, name):
+		return self.__instance_manager.get_object(name)
+
+	def get_save_processor(self):
+		return self.__instance_manager.get_save_processor()
+
+	def show_busy_cursor(self):
+		from cursor import show_busy_textview_cursor
+		return show_busy_textview_cursor(self.__textview)
+
+	def show_normal_cursor(self):
+		from cursor import show_textview_cursor
+		return show_textview_cursor(self.__textview)
+
+	def get_word_before_cursor(self):
+		from cursor import get_word_before_cursor
+		return get_word_before_cursor(self.__textbuffer)
+
+	def can_read_write(self):
+		from utils import check_uri_permission
+		return check_uri_permission(self.uri)
+
+	def find_file(self, file_path):
+		from utils import find_file
+		return find_file(file_path)
+
 	def get_object(self, name):
 		return self.__store.get_object(name)
 
@@ -551,13 +601,67 @@ class Editor(GObject):
 		self.__tip.set_tip(instance, tip)
 		return
 
+	def create_scrollwin(self):
+		from utils import create_scrollwin
+		return create_scrollwin()
+
+	def create_menuitem(self, string, stock_id=None):
+		from utils import create_menuitem
+		return create_menuitem(string, stock_id)
+
+	def convert_color_to_string(self, color):
+		from utils import convert_color_to_spec
+		return convert_color_to_spec(color)
+
+	def convert_color_to_spec(self, style):
+		return self.convert_color_to_string(style)
+
 	def get_cursor_position(self):
 		from cursor import get_cursor_iterator
 		return get_cursor_iterator(self.__textbuffer)
 
+	def create_button_box(self, stock_id, string):
+		return create_button(stock_id, string)
+
+	def create_button(self, stock_id, string):
+		from utils import create_button
+		return create_button(stock_id, string)
+
 	def get_cursor_iterator(self):
 		return self.get_cursor_position()
 
+	def get_cursor_line(self):
+		from cursor import get_cursor_line
+		return get_cursor_line(self.__textbuffer)
+
+	def move_view_to_cursor(self):
+		from cursor import move_view_to_cursor
+		return move_view_to_cursor(self.__textview)
+
+	def word_to_cursor(self):
+		from cursor import word_to_cursor
+		return word_to_cursor(self.__textbuffer)
+
+	def get_cursor_window_coordinates(self):
+		from cursor import get_cursor_window_coordinates
+		return get_cursor_window_coordinates(self.__textview)
+
+	def get_cursor_size(self):
+		from cursor import get_cursor_size
+		return get_cursor_size(self.__textview)
+
+	def select_row(self, treeview):
+		from utils import select_row
+		return select_row(treeview)
+
+	def create_image(self, image_file):
+		from utils import create_image
+		return create_image(image_file)
+
+	def generate_random_number(self, sequence):
+		from utils import generate_random_number
+		return generate_random_number(sequence)
+
 	def mark(self, iterator, alignment="right"):
 		from operator import eq
 		if eq(alignment, "right"):
@@ -589,8 +693,8 @@ class Editor(GObject):
 		return
 
 	def delete_attributes(self, object_ref):
-		from utils import delete_attributes
-		delete_attributes(object_ref)
+		#from utils import delete_attributes
+		#delete_attributes(object_ref)
 		return
 
 	def create_menuitem(self, string, stock_id=None):
@@ -600,7 +704,7 @@ class Editor(GObject):
 	def calculate_resolution_independence(self, window, width, height):
 		from utils import calculate_resolution_independence
 		return calculate_resolution_independence(window, width, height)
-		
+
 	def generate_random_number(self, sequence):
 		from utils import generate_random_number
 		return generate_random_number(sequence)
@@ -686,7 +790,6 @@ class Editor(GObject):
 		self.__statuscontainer.pack_start(self.__statusthree, False, True, 0)
 		self.__maincontainer.resize_children()
 		self.emit("gui-created")
-		self.__response()
 		return False
 
 	def __destroy(self):
@@ -695,7 +798,7 @@ class Editor(GObject):
 		self.__status_image_frame.destroy()
 		self.__statuscontainer.destroy()
 		self.__window.destroy()
-		from utils import delete_attributes, disconnect_signal
+		from utils import disconnect_signal
 		disconnect_signal(self.__signal_id_1, self)
 		disconnect_signal(self.__signal_id_2, self)
 		disconnect_signal(self.__signal_id_3, self)
@@ -730,9 +833,7 @@ class Editor(GObject):
 		@param self: Reference to this editor instance.
 		@type self: An Editor object.
 		"""
-		self.__response()
-		from gobject import idle_add
-		idle_add(self.__create_widgets)
+		self.__create_widgets()
 		return
 
 	def __created_widgets_cb(self, editor):
@@ -750,12 +851,8 @@ class Editor(GObject):
 		@param editor: Reference to the text editor.
 		@type editor: An Editor object.
 		"""
-		self.__response()
 		self.__manager_registration_id = self.__instance_manager.register_editor(self)
-		#start_new_thread(self.__start_core_services, ())
 		self.__start_core_services()
-		#from gobject import timeout_add, PRIORITY_HIGH
-		#timeout_add(3, self.__arrange_widgets, priority=PRIORITY_HIGH)
 		if not self.__file_uri: return
 		from gobject import idle_add
 		idle_add(self.load_uri, self.__file_uri.strip())
@@ -771,12 +868,15 @@ class Editor(GObject):
 		@param self: Reference to the Editor instance.
 		@type self: A Editor object.
 		"""
-		self.__response()
 		# Initialize encoding manager.
 		from EncodingManager import EncodingManager
-		EncodingManager(self, self.__encoding)
+		self.__encoding_manager = EncodingManager(self, self.__encoding)
+		# Initialize file modification monitor
+		from FileModificationMonitor import FileModificationMonitor
+		FileModificationMonitor(self)
 		# Initialize the object that saves files.
-		from FileSaver import FileSaver
+		from NewFileSaver import FileSaver
+#		from FileSaver import FileSaver
 		FileSaver(self)
 		# Initialize the feedback manager.
 		from Feedback import FeedbackManager
@@ -784,17 +884,15 @@ class Editor(GObject):
 		# Initialize the trigger manager.
 		from TriggerManager import TriggerManager
 		self.__trigger_manager = TriggerManager(self)
-		self.__response()
 		return
 
 	def __created_widgets_after_cb(self, editor):
-		from gobject import idle_add
-		idle_add(self.__arrange_widgets)
+		self.__arrange_widgets()
 		return
 
 	def __gui_created_after_cb(self, editor):
-		from gobject import idle_add
-		idle_add(self.__initialize_plugins)
+		from gobject import idle_add, PRIORITY_LOW
+		idle_add(self.__initialize_plugins, priority=PRIORITY_LOW)
 		return
 
 	def __initialize_plugins(self):
@@ -853,10 +951,6 @@ class Editor(GObject):
 		self.__can_load_file = False
 		return False
 
-	def __cursor_moved_cb(self, *args):
-		self.__response()
-		return
-
 ########################################################################
 #
 #						Editor Attributes
@@ -877,16 +971,17 @@ class Editor(GObject):
 		@param type: A String object.
 		"""
 		# A function to improve responsiveness.
-		from utils import response
-		self.__response = response
+		#from utils import response
 		self.__id = id(self)
 		self.__encoding = encoding
 		# An object that manages instances of editors.
 		self.__instance_manager = manager
+		self.__response = manager.response
 		# A file to open or none.
 		self.__file_uri = file_uri
 		# Whether or not the editor can load a file.
 		self.__can_load_file = True
+		self.__encoding_manager = None
 		# The text editor quits only after the termination queue is empty. This
 		# allows objects that need to perform cleanup or metadata operation
 		# to register a unique number in the queue. Registration should occur
@@ -942,3 +1037,16 @@ class Editor(GObject):
 		# A signal emitted after crucial data attributes have been created.
 		self.emit("initialized-attributes")
 		return False
+
+	def __precompile_methods(self):
+		try:
+			from psyco import bind
+			bind(self.__get_textbuffer)
+			bind(self.__get_textview)
+			bind(self.__get_core_plugin_folder)
+			bind(self.__get_is_readonly)
+			bind(self.__get_uri)
+			bind(self.get_cursor_position)
+		except ImportError:
+			pass
+		return False
