@@ -52,11 +52,11 @@ class FeedbackManager(object):
 		self.__signal_id_4 = editor.connect("loaded-document", self.__loaded_document_cb)
 		self.__signal_id_5 = editor.connect("load-error", self.__load_error_cb)
 		self.__signal_id_6 = editor.connect("renamed-document", self.__renamed_document_cb)
-		self.__signal_id_7 = editor.connect("saved-document", self.__saved_document_cb)
+		self.__signal_id_7 = editor.connect_after("saved-document", self.__saved_document_cb)
 		self.__signal_id_8 = editor.connect("enable-readonly", self.__enable_readonly_cb)
 		self.__signal_id_9 = editor.connect("disable-readonly", self.__disable_readonly_cb)
 		self.__signal_id_10 = editor.connect("not-yet-implemented", self.__not_yet_implemented_cb)
-		self.__signal_id_11 = editor.textbuffer.connect("changed", self.__changed_cb)
+		self.__signal_id_11 = editor.connect_after("modified-document", self.__changed_cb)
 		self.__signal_id_12 = editor.connect("gui-created", self.__gui_created_cb)
 		self.__signal_id_13 = editor.connect("reload-document", self.__reload_document_cb)
 
@@ -75,6 +75,7 @@ class FeedbackManager(object):
 		self.__icon_dictionary = self.__create_feedback_icons()
 		self.__spinner = editor.store.get_object("Spinner")
 		self.__message_stack = []
+		self.__error_strings = ("fail", "no", "error", "warning")
 		self.__message_id = None
 		self.__filename = None
 		self.__reset_timer = None
@@ -108,11 +109,11 @@ class FeedbackManager(object):
 		@rtype: A Boolean object.
 		"""
 		self.__is_busy = True
-		from gobject import idle_add
-		idle_add(self.__set_message, message)
-		idle_add(self.__set_icon, icon)
-		idle_add(self.__reset, time)
-		idle_add(self.__beep, icon)
+		from gobject import idle_add, PRIORITY_LOW
+		idle_add(self.__set_message, message, priority=PRIORITY_LOW)
+		idle_add(self.__set_icon, icon, priority=PRIORITY_LOW)
+		idle_add(self.__reset, time, priority=PRIORITY_LOW)
+		idle_add(self.__beep, icon, priority=PRIORITY_LOW)
 		self.__default_message_is_set = False
 		return False
 
@@ -131,9 +132,9 @@ class FeedbackManager(object):
 		"""
 		message_id = self.__editor.generate_random_number(self.__message_stack)
 		self.__message_stack.append((message, icon, message_id))
-		from gobject import idle_add
-		idle_add(self.__set_message, message)
-		idle_add(self.__set_icon, icon)
+		from gobject import idle_add, PRIORITY_LOW
+		idle_add(self.__set_message, message, priority=PRIORITY_LOW)
+		idle_add(self.__set_icon, icon, priority=PRIORITY_LOW)
 		self.__default_message_is_set = False
 		return message_id
 
@@ -154,13 +155,12 @@ class FeedbackManager(object):
 		@rtype: A Boolean object.
 		"""
 		try:
-			from operator import truth
 			for feedback in self.__message_stack:
 				found = self.__remove_message_from_stack(message_id, feedback)
-				if truth(found): break
-			if truth(reset):
-				from gobject import idle_add
-				idle_add(self.__reset_message)
+				if found: break
+			if reset:
+				from gobject import idle_add, PRIORITY_LOW
+				idle_add(self.__reset_message, priority=PRIORITY_LOW)
 		except RuntimeError:
 			pass
 		return False
@@ -225,7 +225,7 @@ class FeedbackManager(object):
 		"""
 		try:
 			from operator import not_
-			if not_(message): return
+			if not_(message): return False
 			statusbar = self.__editor.statusone
 			statusbar.pop(statusbar.context_id)
 			context_id = statusbar.get_context_id(message)
@@ -248,7 +248,7 @@ class FeedbackManager(object):
 		"""
 		try:
 			from operator import not_
-			if not_(icon): return
+			if not_(icon): return False
 			image = self.__editor.status_image
 			frame = self.__editor.status_image_frame
 			image.clear()
@@ -300,8 +300,8 @@ class FeedbackManager(object):
 		@param self: Reference to the FeedbackManager instance.
 		@type self: A FeedbackManager object.
 		"""
-		from operator import truth, not_, is_
-		if truth(self.__message_stack) and not_(self.__editor.is_readonly):
+		from operator import not_, is_
+		if self.__message_stack and not_(self.__editor.is_readonly):
 			self.__set_message_from_stack()
 		elif is_(self.__filename, None):
 			self.__remove_message()
@@ -320,9 +320,8 @@ class FeedbackManager(object):
 		@param self: Reference to the FeedbackManager instance.
 		@type self: A FeedbackManager object.
 		"""
-		from operator import truth
 		from internationalization import msg0044, msg0045
-		if truth(self.__editor.is_readonly):
+		if self.__editor.is_readonly:
 			message = msg0044 % self.__filename
 			self.__set_message(message)
 		else:
@@ -337,10 +336,9 @@ class FeedbackManager(object):
 		@param self: Reference to the FeedbackManager instance.
 		@type self: A FeedbackManager object.
 		"""
-		from operator import truth
-		if truth(self.__editor.is_readonly):
+		if self.__editor.is_readonly:
 			self.__set_icon("readonly")
-		elif truth(self.__editor.file_is_saved):
+		elif self.__editor.file_is_saved:
 			self.__set_icon("new")
 		else:
 			self.__set_icon("edit")
@@ -389,8 +387,7 @@ class FeedbackManager(object):
 		@type time: An Integer object.
 		"""
 		from operator import is_
-		if is_(time, None):
-			time = 3
+		if is_(time, None): time = 3
 		time *= 1000
 		from gobject import timeout_add
 		self.__remove_timer()
@@ -422,7 +419,7 @@ class FeedbackManager(object):
 		@type icon: A String object.
 		"""
 		from operator import contains
-		if contains(("fail", "no", "error", "warning"), icon):
+		if contains(self.__error_strings, icon):
 			from gtk.gdk import beep
 			beep()
 		return False
@@ -440,9 +437,8 @@ class FeedbackManager(object):
 		if uri.startswith("file:///"):
 			from gnomevfs import get_local_path_from_uri
 			local_path = get_local_path_from_uri(uri)
-			from info import home_folder
-			if local_path.startswith(home_folder):
-				self.__filename = local_path.replace(home_folder, "~")
+			if local_path.startswith(self.__editor.home_folder):
+				self.__filename = local_path.replace(self.__editor.home_folder, "~")
 			else:
 				self.__filename = local_path
 		else:
@@ -521,7 +517,7 @@ class FeedbackManager(object):
 		self.__editor.disconnect_signal(self.__signal_id_8, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_9, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_10, self.__editor)
-		self.__editor.disconnect_signal(self.__signal_id_11, self.__editor.textbuffer)
+		self.__editor.disconnect_signal(self.__signal_id_11, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_12, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_13, self.__editor)
 		self.__icon_dictionary.clear()
@@ -552,7 +548,7 @@ class FeedbackManager(object):
 		@type editor: An Editor object.
 		"""
 		self.__destroy()
-		return
+		return False
 
 	def __checking_document_cb(self, editor, uri):
 		"""
@@ -572,7 +568,7 @@ class FeedbackManager(object):
 		self.start_busy_cursor()
 		from internationalization import msg0032
 		self.__message_id = self.set_modal_message(msg0032, "run")
-		return
+		return False
 
 	def __loaded_document_cb(self, editor, uri):
 		"""
@@ -596,7 +592,7 @@ class FeedbackManager(object):
 		self.update_status_message(message, "open")
 		self.stop_spinner()
 		self.stop_busy_cursor()
-		return
+		return False
 
 	def __load_error_cb(self, editor, uri):
 		"""
@@ -618,7 +614,7 @@ class FeedbackManager(object):
 		self.stop_spinner()
 		self.stop_busy_cursor()
 		self.unset_modal_message(self.__message_id)
-		return
+		return False
 
 	def __renamed_document_cb(self, editor, uri):
 		"""
@@ -640,13 +636,13 @@ class FeedbackManager(object):
 		from internationalization import msg0085
 		message = msg0085 % self.__filename
 		self.update_status_message(message, "save", 5)
-		return
+		return False
 
 	def __reload_document_cb(self, *args):
 		from internationalization import msg0489
 		message = msg0489 % self.__filename
 		self.update_status_message(message, "run", 15)
-		return
+		return False
 
 	def __saved_document_cb(self, editor, uri):
 		"""
@@ -661,13 +657,13 @@ class FeedbackManager(object):
 		@param uri: A string representing a file.
 		@type uri: A String object.
 		"""
-		from operator import truth, not_
-		if truth(self.__is_busy): return
-		if not_(self.__default_message_is_set): return
+		from operator import not_
+		if self.__is_busy: return False
+		if not_(self.__default_message_is_set): return False
 		from internationalization import msg0085
 		message = msg0085 % self.__filename
 		self.update_status_message(message, "save", 5)
-		return
+		return False
 
 	def __enable_readonly_cb(self, editor):
 		"""
@@ -681,7 +677,7 @@ class FeedbackManager(object):
 		"""
 		from internationalization import msg0322
 		self.update_status_message(msg0322, "suceed")
-		return
+		return False
 
 	def __disable_readonly_cb(self, editor):
 		"""
@@ -695,7 +691,7 @@ class FeedbackManager(object):
 		"""
 		from internationalization import msg0324
 		self.update_status_message(msg0324, "suceed")
-		return
+		return False
 
 	def __not_yet_implemented_cb(self, editor):
 		"""
@@ -709,7 +705,7 @@ class FeedbackManager(object):
 		"""
 		message = "Not yet implemented"
 		self.update_status_message(message, "warning")
-		return
+		return False
 
 	def __changed_cb(self, *args):
 		"""
@@ -722,14 +718,13 @@ class FeedbackManager(object):
 		@type args: A Tuple object.
 		"""
 		from operator import not_, ne, is_
-		if is_(self.__filename, None): return
-		if not_(self.__default_message_is_set): return
+		if is_(self.__filename, None): return False
+		if not_(self.__default_message_is_set): return False
 		from gtk import STOCK_EDIT
-		if ne(self.__editor.status_image.get_stock()[0], STOCK_EDIT):
-			self.__set_icon("edit")
+		if ne(self.__editor.status_image.get_stock()[0], STOCK_EDIT): self.__set_icon("edit")
 		return False
 
 	def __gui_created_cb(self, *args):
 		self.__remove_message()
 		self.__remove_icon()
-		return
+		return False
