@@ -28,7 +28,7 @@ This module documents a class that saves files.
 @contact: mystilleef@gmail.com
 """
 
-PRIORITY = 0
+PRIORITY = 10
 
 class FileSaver(object):
 	"""
@@ -61,7 +61,7 @@ class FileSaver(object):
 		self.__signal_id_11 = editor.connect_after("renamed-document", self.__renamed_document_cb)
 		self.__signal_id_12 = editor.connect_after("reload-document", self.__reload_document_cb)
 		from gobject import timeout_add
-		timeout_add(100, self.__check_encoding_manager)
+		timeout_add(500, self.__check_encoding_manager)
 
 	def __init_attributes(self, editor):
 		"""
@@ -763,8 +763,8 @@ class FileSaver(object):
 		@param editor: Reference to the text editor.
 		@type editor: An Editor object.
 		"""
-		from gobject import idle_add
-		idle_add(self.save_file)
+		from gobject import idle_add, PRIORITY_HIGH
+		idle_add(self.save_file, priority = PRIORITY_HIGH)
 		return
 
 	def __saved_document_cb(self, editor, uri):
@@ -795,10 +795,10 @@ class FileSaver(object):
 		"""
 		if textbuffer.get_modified() is False: return False
 		self.__editor.emit("modified-document")
-		if self.__editor.uri is None: return False
+		if self.__editor.uri is None: return True
 		from gobject import timeout_add, PRIORITY_LOW
 		self.__save_timer = timeout_add(21000, self.__save_file_timeout_cb, priority=PRIORITY_LOW)
-		return False
+		return True
 
 	def __reload_document_cb(self, *args):
 		self.__remove_save_timer()
@@ -820,8 +820,8 @@ class FileSaver(object):
 		self.__stop_monitoring_file()
 		if self.__editor.is_readonly: self.__toggle_readonly = True
 		self.__should_rename = True
-		from gobject import idle_add
-		idle_add(self.save_file)
+		from gobject import idle_add, PRIORITY_HIGH
+		idle_add(self.save_file, priority = PRIORITY_HIGH)
 		return
 
 	def __updated_cb(self, store, name):
@@ -832,7 +832,7 @@ class FileSaver(object):
 
 	def __check_encoding_manager(self):
 		if self.__encoding_manager: return False
-		self.__encoding_manager = self.__editor.store.get_object("EncodingManager")
+		self.__encoding_manager = self.__editor.get_object("EncodingManager")
 		return True
 
 	def __file_changed_cb(self, monitor_uri, info_uri, event_type):
@@ -867,3 +867,4 @@ class FileSaver(object):
 	def __renamed_document_cb(self, *args):
 		self.__start_monitoring_file()
 		return
+
