@@ -65,7 +65,6 @@ class ScribesTextView(SourceView):
 		self.__signal_id_7 = self.connect("copy-clipboard", self.__copy_clipboard_cb)
 		self.__signal_id_8 = self.connect("cut-clipboard", self.__cut_clipboard_cb)
 		self.__signal_id_9 = self.connect("paste-clipboard", self.__paste_clipboard_cb)
-		self.__signal_id_10 = self.connect_after("paste-clipboard", self.__paste_clipboard_after_cb)
 		self.__signal_id_11 = self.connect("button-press-event", self.__button_press_event_cb)
 		self.__signal_id_12 = editor.connect("checking-document", self.__checking_document_cb)
 		self.__signal_id_13 = editor.connect("loaded-document", self.__loaded_document_cb)
@@ -78,8 +77,6 @@ class ScribesTextView(SourceView):
 		self.__signal_id_20 = editor.connect("hide-bar", self.__hide_bar_cb)
 		self.__signal_id_21 = editor.connect("close-document", self.__close_document_cb)
 		self.__signal_id_22 = editor.connect("close-document-no-save", self.__close_document_cb)
-		self.__signal_id_23 = self.connect("scroll-event", self.__scroll_event_cb)
-		self.__signal_id_24 = self.connect("move-cursor", self.__move_cursor_cb)
 		self.__signal_id_25 = editor.connect("reload-document", self.__reload_document_cb)
 		# GConf notification monitors.
 		self.__client.notify_add("/apps/scribes/font", self.__font_changed_cb)
@@ -134,8 +131,6 @@ class ScribesTextView(SourceView):
 		from gtk.gdk import ACTION_COPY, BUTTON1_MASK, ACTION_DEFAULT
 		self.drag_dest_set(DEST_DEFAULT_ALL, targets, ACTION_COPY)
 		self.set_property("buffer", self.__editor.textbuffer)
-		from gtk import RESIZE_PARENT
-		self.set_resize_mode(RESIZE_PARENT)
 		self.set_highlight_current_line(True)
 		self.set_show_line_numbers(True)
 		self.set_auto_indent(True)
@@ -224,7 +219,8 @@ class ScribesTextView(SourceView):
 			screen.
 		@type event: A gtk.Event object.
 		"""
-		self.__refresh_view()
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
 		return False
 
 	def __drag_motion_cb(self, textview, context, x, y, time):
@@ -369,14 +365,13 @@ class ScribesTextView(SourceView):
 		@param editor: An instance of the text editor.
 		@type editor: An Editor object.
 		"""
-		self.handler_block(self.__signal_id_23)
-		self.handler_block(self.__signal_id_24)
 		self.set_property("editable", False)
 		self.set_property("highlight-current-line", False)
 		self.set_property("cursor-visible", False)
 		self.set_property("sensitive", False)
-		self.__refresh_view()
-		return
+#		from gobject import idle_add
+#		idle_add(self.__refresh_view)
+		return False
 
 	def __loaded_document_cb(self, editor, uri):
 		"""
@@ -389,18 +384,17 @@ class ScribesTextView(SourceView):
 		@param editor: An instance of the text editor.
 		@type editor: An Editor object.
 		"""
-		self.handler_unblock(self.__signal_id_23)
-		self.handler_unblock(self.__signal_id_24)
 		self.set_property("sensitive", True)
 		self.set_property("highlight-current-line", True)
 		self.set_property("cursor-visible", True)
 		self.set_property("editable", True)
-		self.__refresh_view()
-		return
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
+		return False
 
 	def __reload_document_cb(self, *args):
 		self.set_property("editable", False)
-		return
+		return False
 
 	def __load_error_cb(self, editor, uri):
 		"""
@@ -413,15 +407,13 @@ class ScribesTextView(SourceView):
 		@param editor: An instance of the text editor.
 		@type editor: An Editor object.
 		"""
-		self.handler_unblock(self.__signal_id_23)
-		self.handler_unblock(self.__signal_id_24)
 		self.set_property("sensitive", True)
 		self.set_property("cursor-visible", True)
 		self.set_property("highlight-current-line", True)
 		self.set_property("editable", True)
 		from cursor import move_view_to_cursor
 		move_view_to_cursor(self)
-		return
+		return False
 
 	def __enable_readonly_cb(self, editor):
 		"""
@@ -437,8 +429,9 @@ class ScribesTextView(SourceView):
 		self.set_property("highlight-current-line", False)
 		self.set_property("cursor-visible", False)
 		self.set_property("show-line-numbers", False)
-		self.__refresh()
-		return
+#		from gobject import idle_add
+#		idle_add(self.__refresh_view)
+		return False
 
 	def __disable_readonly_cb(self, editor):
 		"""
@@ -455,8 +448,9 @@ class ScribesTextView(SourceView):
 		self.set_property("highlight-current-line", True)
 		self.set_property("cursor-visible", True)
 		self.set_property("show-line-numbers", True)
-		self.__refresh_view()
-		return
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
+		return False
 
 	def __renamed_document_cb(self, editor, uri):
 		"""
@@ -473,8 +467,9 @@ class ScribesTextView(SourceView):
 		self.set_property("highlight-current-line", True)
 		self.set_property("cursor-visible", True)
 		self.set_property("show-line-numbers", True)
-		self.__refresh_view()
-		return
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
+		return False
 
 	def __show_bar_cb(self, editor, bar):
 		"""
@@ -494,8 +489,7 @@ class ScribesTextView(SourceView):
 		self.set_property("editable", False)
 		self.set_property("cursor-visible", False)
 		self.set_property("accepts-tab", False)
-		self.__editor.response()
-		return
+		return False
 
 	def __hide_bar_cb(self, editor, bar):
 		"""
@@ -514,8 +508,9 @@ class ScribesTextView(SourceView):
 		self.set_property("editable", True)
 		self.set_property("cursor-visible", True)
 		self.set_property("accepts-tab", True)
-		self.__refresh_view()
-		return
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
+		return False
 
 	def __focus_in_event_cb(self, textview, event):
 		"""
@@ -535,7 +530,9 @@ class ScribesTextView(SourceView):
 		@type: A Boolean Object.
 		"""
 		if self.__bar_is_visible is False:
-			self.__refresh_view()
+			self.grab_focus()
+			#from gobject import idle_add
+			#idle_add(self.__refresh_view)
 		return False
 
 	def __button_press_event_cb(self, textview, event):
@@ -583,7 +580,9 @@ class ScribesTextView(SourceView):
 		return False
 
 	def __hide_dialog_cb(self, *args):
-		self.__refresh_view()
+		self.grab_focus()
+		#from gobject import idle_add
+		#idle_add(self.__refresh_view)
 		return
 
 	def __copy_clipboard_cb(self, textview):
@@ -612,7 +611,6 @@ class ScribesTextView(SourceView):
 
 		# Get selection bounds
 		selection = textbuffer.get_selection_bounds()
-		self.__refresh_view()
 		# Depending on whether or not text is selected and copied, send appropriate
 		# feedback back to the user via the statusbar.
 		if selection:
@@ -645,30 +643,7 @@ class ScribesTextView(SourceView):
 			feedback.update_status_message(msg0094, "fail")
 		return False
 
-	def __paste_clipboard_after_cb(self, textview):
-		self.__refresh_view()
-		return False
-
-	def __scroll_event_cb(self, *args):
-		from gobject import idle_add, PRIORITY_LOW, source_remove
-		try:
-			source_remove(self.__scroll_id)
-		except:
-			pass
-		self.__scroll_id = idle_add(self.__test_response, priority=PRIORITY_LOW)
-		return False
-
-	def __move_cursor_cb(self, *args):
-		from gobject import idle_add, PRIORITY_LOW, source_remove
-		try:
-			source_remove(self.__move_id)
-		except:
-			pass
-		self.__move_id = idle_add(self.__test_response, priority=PRIORITY_LOW)
-		return False
-
-	def __test_response(self):
-		self.__editor.response()
+	def __make_responsive(self):
 		return False
 
 	def __close_document_cb(self, editor):
@@ -712,7 +687,6 @@ class ScribesTextView(SourceView):
 		from pango import FontDescription
 		new_font = FontDescription(entry.value.to_string())
 		self.modify_font(new_font)
-		self.__refresh_view()
 		return
 
 	def __tab_width_cb(self, client, cnxn_id, entry, data):
@@ -735,7 +709,6 @@ class ScribesTextView(SourceView):
 		@type data: Any type object.
 		"""
 		self.set_tabs_width(int(entry.value.to_string()))
-		self.__refresh_view()
 		return
 
 	def __text_wrapping_cb(self, client, cnxn_id, entry, data):
@@ -762,7 +735,6 @@ class ScribesTextView(SourceView):
 			self.set_wrap_mode(WRAP_WORD)
 		else:
 			self.set_wrap_mode(WRAP_NONE)
-		self.__refresh_view()
 		return
 
 	def __margin_position_cb(self, client, cnxn_id, entry, data):
@@ -786,7 +758,6 @@ class ScribesTextView(SourceView):
 		@type data: Any type object.
 		"""
 		self.set_margin(int(entry.value.to_string()))
-		self.__refresh_view()
 		return
 
 	def __show_margin_cb(self, client, cnxn_id, entry, data):
@@ -810,7 +781,6 @@ class ScribesTextView(SourceView):
 		@type data: Any type object.
 		"""
 		self.set_show_margin(entry.value.get_bool())
-		self.__refresh_view()
 		return
 
 	def __spell_check_cb(self, client, cnxn_id, entry, data):
@@ -844,7 +814,6 @@ class ScribesTextView(SourceView):
 				pass
 		else:
 			self.__spell_checker.detach()
-		self.__refresh_view()
 		return
 
 	def __themes_cb(self, client, cnxn_id, entry, data):
@@ -892,7 +861,6 @@ class ScribesTextView(SourceView):
 			from gtk import STATE_NORMAL
 			self.modify_base(STATE_NORMAL, background_color)
 			self.modify_text(STATE_NORMAL, foreground_color)
-		self.__refresh_view()
 		return
 
 	def __foreground_cb(self, client, cnxn_id, entry, data):
@@ -919,7 +887,8 @@ class ScribesTextView(SourceView):
 		foreground_color = color_parse(color)
 		from gtk import STATE_NORMAL
 		self.modify_text(STATE_NORMAL, foreground_color)
-		self.__refresh_view()
+		from gobject import idle_add
+		idle_add(self.__refresh_view)
 		return
 
 	def __background_cb(self, client, cnxn_id, entry, data):
@@ -946,7 +915,6 @@ class ScribesTextView(SourceView):
 		background_color = color_parse(color)
 		from gtk import STATE_NORMAL
 		self.modify_base(STATE_NORMAL, background_color)
-		self.__refresh_view()
 		return
 
 	def __use_tabs_cb(self, client, cnxn_id, entry, data):
@@ -970,7 +938,6 @@ class ScribesTextView(SourceView):
 		"""
 		use_tabs = client.get_bool("/apps/scribes/use_tabs")
 		self.set_insert_spaces_instead_of_tabs(not use_tabs)
-		self.__refresh_view()
 		return
 
 	def __syntax_cb(self, client, cnxn_id, entry, data):
@@ -995,11 +962,8 @@ class ScribesTextView(SourceView):
 		from syntax import activate_syntax_highlight
 		from utils import get_language
 		language = None
-		if self.__editor.uri:
-			language = get_language(self.__editor.uri)
+		if self.__editor.uri: language = get_language(self.__editor.uri)
 		activate_syntax_highlight(self.get_buffer(), language)
-		from gobject import idle_add, PRIORITY_LOW
-		idle_add(self.__refresh, priority=PRIORITY_LOW)
 		return
 
 	def __refresh_view(self):
@@ -1009,20 +973,21 @@ class ScribesTextView(SourceView):
 		@param self: Reference to the ScribesTextView instance.
 		@type self: A ScribesTextView object.
 		"""
-		from gobject import idle_add, PRIORITY_LOW
-		idle_add(self.__refresh, priority=PRIORITY_LOW)
 		self.grab_focus()
-		return
+#		self.__make_responsive()
+#		from gobject import idle_add, PRIORITY_LOW
+#		idle_add(self.__refresh, priority=PRIORITY_LOW)
+		return False
 
 	def __refresh(self):
-		self.queue_draw()
-		self.queue_resize()
-		self.resize_children()
-		try:
-			self.window.process_updates(True)
-		except:
-			pass
-		self.__editor.response()
+#		self.queue_draw()
+#		self.queue_resize()
+#		self.resize_children()
+#		try:
+#			self.window.process_updates(True)
+#		except:
+#			pass
+#		self.__make_responsive()
 		return False
 
 	def __destroy(self):
@@ -1042,7 +1007,6 @@ class ScribesTextView(SourceView):
 		self.__editor.disconnect_signal(self.__signal_id_7, self)
 		self.__editor.disconnect_signal(self.__signal_id_8, self)
 		self.__editor.disconnect_signal(self.__signal_id_9, self)
-		self.__editor.disconnect_signal(self.__signal_id_10, self)
 		self.__editor.disconnect_signal(self.__signal_id_11, self)
 		self.__editor.disconnect_signal(self.__signal_id_12, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_13, self.__editor)
@@ -1055,8 +1019,6 @@ class ScribesTextView(SourceView):
 		self.__editor.disconnect_signal(self.__signal_id_20, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_21, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_22, self.__editor)
-		self.__editor.disconnect_signal(self.__signal_id_23, self)
-		self.__editor.disconnect_signal(self.__signal_id_24, self)
 		self.__editor.disconnect_signal(self.__signal_id_25, self.__editor)
 		# Unregister object so that editor can quit.
 		self.__editor.unregister_object(self.__registration_id)
