@@ -42,6 +42,7 @@ class ScribesWindow(Window):
 		@param self: Reference to the text editor's window instance.
 		@type self: A ScribesWindow object.
 		"""
+		self.__precompile_methods()
 		Window.__init__(self)
 		self.__init_attributes(editor)
 		self.__set_properties()
@@ -54,7 +55,7 @@ class ScribesWindow(Window):
 		self.__signal_id_7 = self.__editor.connect("load-error", self.__load_error_cb)
 		self.__signal_id_8 = self.__editor.connect("enable-readonly", self.__enable_readonly_cb)
 		self.__signal_id_9 = self.__editor.connect("disable-readonly", self.__disable_readonly_cb)
-		self.__signal_id_10 = self.__editor.connect("saved-document", self.__saved_document_cb)
+		self.__signal_id_10 = self.__editor.connect_after("saved-document", self.__saved_document_cb)
 		self.__signal_id_11 = self.__editor.connect("close-document", self.__close_document_cb)
 		self.__signal_id_12 = self.__editor.connect("enable-fullscreen", self.__enable_fullscreen_cb)
 		self.__signal_id_13 = self.__editor.connect("disable-fullscreen", self.__disable_fullscreen_cb)
@@ -62,12 +63,12 @@ class ScribesWindow(Window):
 		self.__signal_id_15 = self.__editor.connect("hide-bar", self.__hide_bar_cb)
 		self.__signal_id_16 = self.connect("key-press-event", self.__key_press_event_cb)
 		self.__signal_id_17 = self.connect_after("focus-out-event", self.__focus_out_event_cb)
+		self.__signal_id_24 = self.connect_after("focus-in-event", self.__focus_in_event_cb)
 		self.__signal_id_19 = self.__editor.connect("renamed-document", self.__renamed_document_cb)
 		self.__signal_id_20 = self.__editor.connect("close-document-no-save", self.__close_document_no_save_cb)
 		self.__signal_id_21 = self.__editor.connect("checking-document", self.__checking_document_cb)
 		self.__signal_id_22 = self.__editor.connect("buffer-created", self.__created_widgets_cb)
 		self.__signal_id_23 = self.__editor.connect("reload-document", self.__reload_document_cb)
-		editor.response()
 
 	def __init_attributes(self, editor):
 		"""
@@ -89,6 +90,7 @@ class ScribesWindow(Window):
 		self.__is_mapped = False
 		# True if the window is maximized.
 		self.__is_maximized = False
+		self.__window_position_timer = None
 		self.__uri = None
 		self.__positioned = False
 		self.__signal_id_1 = self.__signal_id_2 = self.__signal_id_3 = None
@@ -184,8 +186,6 @@ class ScribesWindow(Window):
 		@rtype: A Boolean object.
 		"""
 		if self.__is_first_time:
-			self.resize_children()
-			self.window.process_updates(True)
 			self.__is_first_time = False
 			self.__is_mapped = True
 		return True
@@ -209,6 +209,23 @@ class ScribesWindow(Window):
 		# Save a document when the text editor's window loses focus.
 		if self.__editor.uri and self.__editor.file_is_saved is False and self.__editor.is_readonly is False:
 			self.__editor.trigger("save_file")
+		xcoordinate, ycoordinate = self.get_position()
+		width, height = self.get_size()
+		is_maximized = self.__is_maximized
+		# Update the metadata database with the size and position of the window.
+		from gobject import idle_add
+		idle_add(self.__update_position, is_maximized, xcoordinate, ycoordinate, width, height)
+#		from gtk.gdk import flush
+#		flush()
+		return False
+		
+	def __focus_in_event_cb(self, *args):
+		xcoordinate, ycoordinate = self.get_position()
+		width, height = self.get_size()
+		is_maximized = self.__is_maximized
+		# Update the metadata database with the size and position of the window.
+		from gobject import idle_add
+		idle_add(self.__update_position, is_maximized, xcoordinate, ycoordinate, width, height)
 		return False
 
 	def __state_event_cb(self, window, event):
@@ -229,8 +246,6 @@ class ScribesWindow(Window):
 		@return: True to prevent propagation of the signal to parent widgets.
 		@rtype: A Boolean object.
 		"""
-		self.queue_resize()
-		self.resize_children()
 		from operator import eq, contains
 		from gtk.gdk import WINDOW_STATE_MAXIMIZED, WINDOW_STATE_FULLSCREEN
 		from gtk.gdk import WINDOW_STATE_ICONIFIED
@@ -268,7 +283,8 @@ class ScribesWindow(Window):
 		@param editor: An instance of the text editor.
 		@type editor: An Editor object.
 		"""
-		self.__editor.textbuffer.handler_unblock(self.__signal_id_18)
+		#self.__editor.textbuffer.handler_unblock(self.__signal_id_18)
+		self.__editor.handler_unblock(self.__signal_id_18)
 		self.__uri = uri
 		self.set_title(self.__title)
 		self.show_all()
@@ -290,18 +306,19 @@ class ScribesWindow(Window):
 		@param editor: An instance of the text editor.
 		@type editor: An Editor object.
 		"""
-		self.__editor.textbuffer.handler_unblock(self.__signal_id_18)
+		#self.__editor.textbuffer.handler_unblock(self.__signal_id_18)
+		self.__editor.handler_unblock(self.__signal_id_18)
 		from internationalization import msg0025
 		self.__uri = None
 		self.__title = None
 		self.set_title(msg0025)
-		if self.__is_mapped is False:
-			self.__editor.emit("close-document-no-save")
+		if self.__is_mapped is False: self.__editor.emit("close-document-no-save")
 		return
 
 	def __checking_document_cb(self, editor, uri):
 		self.__uri = uri
-		self.__editor.textbuffer.handler_block(self.__signal_id_18)
+		#self.__editor.textbuffer.handler_block(self.__signal_id_18)
+		self.__editor.handler_block(self.__signal_id_18)
 		# Set the titlebar to show the file is currently being loaded.
 		self.__determine_title(uri)
 		from internationalization import msg0335
@@ -349,12 +366,12 @@ class ScribesWindow(Window):
 		@type editor: An Editor object.
 		"""
 		if self.__editor.will_load_document: return
-		from gobject import timeout_add
 		self.__show_window()
 		return
 
 	def __created_widgets_cb(self, editor):
-		self.__signal_id_18 = self.__editor.textbuffer.connect("changed", self.__changed_cb)
+		#self.__signal_id_18 = self.__editor.textbuffer.connect("changed", self.__changed_cb)
+		self.__signal_id_18 = self.__editor.connect_after("modified-document", self.__changed_cb)
 		return
 
 	def __changed_cb(self, textbuffer):
@@ -374,10 +391,8 @@ class ScribesWindow(Window):
 		@return: True to propagate signals to parent widgets.
 		@rtype: A Boolean object.
 		"""
-		if self.__uri:
-			from operator import eq
-			if eq(self.get_title(), self.__title):
-				self.set_title("*" + self.__title)
+		if not self.__uri: return True
+		self.set_title("*" + self.__title)
 		return True
 
 	def __enable_fullscreen_cb(self, editor):
@@ -392,8 +407,6 @@ class ScribesWindow(Window):
 		"""
 		self.__is_fullscreen = True
 		self.fullscreen()
-		self.resize_children()
-		self.queue_resize()
 		return
 
 	def __disable_fullscreen_cb(self, editor):
@@ -408,8 +421,6 @@ class ScribesWindow(Window):
 		"""
 		self.__is_fullscreen = False
 		self.unfullscreen()
-		self.resize_children()
-		self.queue_resize()
 		return
 
 	def __show_bar_cb(self, editor, bar):
@@ -427,7 +438,6 @@ class ScribesWindow(Window):
 		"""
 		self.__bar = bar
 		self.__bar_is_visible = True
-		self.__editor.response()
 		return
 
 	def __hide_bar_cb(self, editor, bar):
@@ -444,8 +454,6 @@ class ScribesWindow(Window):
 		@type bar: A ScribesBar object.
 		"""
 		self.__bar_is_visible = False
-		self.window.process_updates(True)
-		self.__editor.response()
 		return
 
 	def __key_press_event_cb(self, window, event):
@@ -501,7 +509,8 @@ class ScribesWindow(Window):
 		"""
 		self.__position_window()
 		self.show_all()
-		self.__editor.response()
+		from gtk.gdk import notify_startup_complete
+		notify_startup_complete()
 		return False
 
 	def __position_window(self):
@@ -516,11 +525,15 @@ class ScribesWindow(Window):
 		@type self: A ScribesWindow object.
 		"""
 		try:
-			if not self.__uri: return
+			if self.__uri:
+				uri = self.__uri
+			else:
+				uri = '<EMPTY>'
 			# Get window position from the position database, if possible.
 			from position_metadata import get_window_position_from_database
 			maximize, width, height, xcoordinate, ycoordinate = \
-				get_window_position_from_database(self.__uri)
+				get_window_position_from_database(uri)# or \
+				#get_window_position_from_database(empty_uri)
 			if maximize:
 				self.maximize()
 			else:
@@ -529,7 +542,6 @@ class ScribesWindow(Window):
 				self.resize(width, height)
 		except TypeError:
 			pass
-		self.__editor.response()
 		return False
 
 	def __saved_document_cb(self, editor, uri):
@@ -544,7 +556,7 @@ class ScribesWindow(Window):
 		@type editor: An Editor object.
 		"""
 		self.set_title(self.__title)
-		return
+		return False
 
 	def __close_document_cb(self, editor):
 		"""
@@ -560,35 +572,33 @@ class ScribesWindow(Window):
 		@param editor: An instance of the text editor's buffer.
 		@type editor: An Editor object.
 		"""
-		self.__editor.response()
 		self.__editor.disconnect_signal(self.__signal_id_17, self)
 		# Get the text editor's window size and position.
 		xcoordinate, ycoordinate = self.get_position()
 		width, height = self.get_size()
 		is_maximized = self.__is_maximized
 		# Update the metadata database with the size and position of the window.
-		from gobject import timeout_add
-		timeout_add(10, self.__update_position_metadata, is_maximized, xcoordinate, ycoordinate, width, height)
+		from gobject import idle_add
+		idle_add(self.__update_position_metadata, is_maximized, xcoordinate, ycoordinate, width, height)
 		self.hide_all()
-		self.__editor.response()
-		return
+		return False
 
 	def __close_document_no_save_cb(self, editor):
 		self.__editor.disconnect_signal(self.__signal_id_17, self)
 		self.__destroy()
-		return
+		return False
 
 	def __renamed_document_cb(self, editor, uri):
 		self.__uri = uri
 		self.__determine_title(self.__uri)
 		self.set_title(self.__title)
-		return
+		return False
 
 	def __reload_document_cb(self, *args):
 		from internationalization import msg0489
 		message = msg0489 % (self.__uri)
 		self.set_title(message)
-		return
+		return False
 
 ########################################################################
 #
@@ -608,23 +618,53 @@ class ScribesWindow(Window):
 			to, a text document.
 		@type uri: A String object.
 		"""
-		from position_metadata import update_window_position_in_database
-		if self.__uri:
-			if is_maximized:
-				window_position = (True, None, None, None, None)
-				update_window_position_in_database(self.__uri, window_position)
-			else:
-				window_position = (False, width, height, xcoordinate, ycoordinate)
-				update_window_position_in_database(self.__uri, window_position)
+		self.__stop_window_position_timer()
+		self.__update_position(is_maximized, xcoordinate, ycoordinate, width, height)
 		self.__destroy()
 		return False
 
-	def __determine_title(self, uri):
-		from gnomevfs import URI
-		self.__title = URI(uri).short_name
+	def __update_position(self, is_maximized, xcoordinate, ycoordinate, width, height):
+		if self.__uri:
+			uri = self.__uri
+		else:
+			uri = '<EMPTY>'
+		from position_metadata import update_window_position_in_database
+		if is_maximized:
+			window_position = (True, None, None, None, None)
+			update_window_position_in_database(str(uri), window_position)
+		else:
+			window_position = (False, width, height, xcoordinate, ycoordinate)
+			update_window_position_in_database(str(uri), window_position)
+		return False
+
+	def __stop_window_position_timer(self):
+		try:
+			from gobject import source_remove
+			source_remove(self.__window_position_timer)
+		except:
+			pass
 		return
 
+	def __determine_title(self, uri):
+		from gnomevfs import URI
+		self.__title = URI(uri).short_name.encode("utf-8")
+		return False
+
+	def __precompile_methods(self):
+		try:
+			from psyco import bind
+			bind(self.__key_press_event_cb)
+		except ImportError:
+			pass
+		return False
+
 	def __destroy(self):
+		"""
+		Destroy object.
+
+		@param self: Reference to the Window instance.
+		@type self: A Window object.
+		"""
 		self.__editor.disconnect_signal(self.__signal_id_17, self)
 		self.__editor.disconnect_signal(self.__signal_id_1, self)
 		self.__editor.disconnect_signal(self.__signal_id_2, self)
@@ -642,14 +682,15 @@ class ScribesWindow(Window):
 		self.__editor.disconnect_signal(self.__signal_id_13, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_14, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_15, self.__editor)
-		self.__editor.disconnect_signal(self.__signal_id_18, self.__editor.textbuffer)
+		#self.__editor.disconnect_signal(self.__signal_id_18, self.__editor.textbuffer)
+		self.__editor.disconnect_signal(self.__signal_id_18, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_19, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_20, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_21, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_22, self.__editor)
 		self.__editor.disconnect_signal(self.__signal_id_23, self.__editor)
+		self.__editor.disconnect_signal(self.__signal_id_24, self.__editor)
 		self.__editor.unregister_object(self.__termination_id)
 		del self
 		self = None
 		return
-
