@@ -50,9 +50,6 @@ class ScribesToolButton(ToolButton):
 		from tooltips import create_tooltips
 		self.tooltips = create_tooltips()
 		self.__set_properties()
-		self.resize_children()
-		from utils import response
-		response()
 
 	def __set_properties(self):
 		"""
@@ -68,8 +65,6 @@ class ScribesToolButton(ToolButton):
 		self.set_expand(False)
 		self.set_use_drag_window(False)
 		self.set_is_important(False)
-		from gtk import RESIZE_PARENT
-		self.set_property("resize-mode", RESIZE_PARENT)
 		return False
 
 class NewToolButton(ScribesToolButton):
@@ -112,7 +107,7 @@ class NewToolButton(ScribesToolButton):
 		@param editor: Reference to the text editor.
 		@type editor: An Editor object.
 		"""
-		editor.triggermanager.trigger("new_window")
+		editor.trigger("new_window")
 		return True
 
 class OpenToolButton(MenuToolButton):
@@ -158,7 +153,7 @@ class OpenToolButton(MenuToolButton):
 		@return: True to propagate signals to parent widgets.
 		@type: A Boolean Object.
 		"""
-		editor.triggermanager.trigger("show_open_dialog")
+		editor.trigger("show_open_dialog")
 		return True
 
 class SaveToolButton(ScribesToolButton):
@@ -206,7 +201,7 @@ class SaveToolButton(ScribesToolButton):
 		@return: True to propagate signals to parent widgets.
 		@type: A Boolean Object.
 		"""
-		editor.triggermanager.trigger("show_save_dialog")
+		editor.trigger("show_save_dialog")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -298,7 +293,7 @@ class PrintToolButton(ScribesToolButton):
 		@return: True to propagate signals to parent widgets.
 		@type: A Boolean Object.
 		"""
-		editor.triggermanager.trigger("show_print_dialog")
+		editor.trigger("show_print_dialog")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -371,7 +366,7 @@ class UndoToolButton(ScribesToolButton):
 		editor.connect("gui-created", self.__toolbutton_gui_created_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("undo_action")
+		editor.trigger("undo_action")
 		return True
 
 	def __toolbutton_enable_readonly_cb(self, editor):
@@ -486,7 +481,7 @@ class RedoToolButton(ScribesToolButton):
 		editor.connect("gui-created", self.__toolbutton_gui_created_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("redo_action")
+		editor.trigger("redo_action")
 		return True
 
 	def __toolbutton_gui_created_cb(self, editor):
@@ -603,7 +598,7 @@ class GotoToolButton(ScribesToolButton):
 		editor.connect("load-error", self.__toolbutton_load_error_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("show_gotobar")
+		editor.trigger("show_gotobar")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -672,7 +667,7 @@ class SearchToolButton(ScribesToolButton):
 		editor.connect("load-error", self.__toolbutton_load_error_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("show_findbar")
+		editor.trigger("show_findbar")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -743,7 +738,7 @@ class ReplaceToolButton(ScribesToolButton):
 		editor.connect("load-error", self.__toolbutton_load_error_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("show_replacebar")
+		editor.trigger("show_replacebar")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -839,7 +834,7 @@ class PrefToolButton(MenuToolButton):
 		editor.connect("load-error", self.__toolbutton_load_error_cb)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("show_preference_dialog")
+		editor.trigger("show_preference_dialog")
 		return True
 
 	def __toolbutton_loading_document_cb(self, editor, uri):
@@ -905,7 +900,7 @@ class HelpToolButton(ScribesToolButton):
 		self.connect("clicked", self.__toolbutton_clicked_cb, editor)
 
 	def __toolbutton_clicked_cb(self, toolbutton, editor):
-		editor.triggermanager.trigger("show_user_guide")
+		editor.trigger("show_user_guide")
 		return True
 
 class Spinner(ToolItem):
