@@ -48,7 +48,6 @@ def calculate_resolution_independence(window, width, height):
 	@return: The width and height to set the window objects to.
 	@rtype: A Tuple object containing the suggested width and height to set
 		windows to.
-
 	"""
 	screen = window.get_screen()
 	number = screen.get_number()
@@ -103,11 +102,9 @@ def create_scrollwin():
 	from gtk import ScrolledWindow, RESIZE_PARENT, POLICY_AUTOMATIC
 	from gtk import SHADOW_IN
 	scrollwin = ScrolledWindow()
-	scrollwin.set_resize_mode(RESIZE_PARENT)
 	scrollwin.set_border_width(1)
 	scrollwin.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
 	scrollwin.set_shadow_type(SHADOW_IN)
-	scrollwin.resize_children()
 	return scrollwin
 
 def get_language(uri):
@@ -270,8 +267,7 @@ def generate_random_number(sequence):
 				if number == item:
 					exit = False
 					break
-		if exit:
-			break
+		if exit: break
 	return number
 
 def check_uri_permission(uri):
@@ -302,25 +298,9 @@ def check_uri_permission(uri):
 		writable_scheme = ["ssh", "sftp", "smb", "dav", "davs", "ftp"]
 		from gnomevfs import get_uri_scheme
 		scheme = get_uri_scheme(uri)
-		if not scheme in writable_scheme:
-			value = False
+		if not scheme in writable_scheme: value = False
 	return value
 
-from gobject import main_context_default
-context = main_context_default()
-pending = context.pending
-iteration = context.iteration
-
-def response():
-	"""
-	Allow scribes GUI to be responsive when performing tasks that can
-	potentially	lock the GUI.
-	"""
-	global pending, iteration
-	while pending():
-		iteration(False)
-	return False
-
 def get_file_size(uri):
 	"""
 	Get the size of a file.
@@ -391,9 +371,7 @@ def calculate_completion_window_position(editor, width, height):
 
 	@param height: The height of the text editor's completion window.
 	@type height: An integer object.
-
 	"""
-
 	# The flag is true when the position of the word completion window needs to
 	# adjusted accross the y-axis.
 	editor.y_coordinate_flag = False
@@ -491,12 +469,6 @@ def convert_color_to_spec(color):
 	string = "#" + red + green + blue
 	return string
 
-def start_psyco():
-	"""
-	Use the psyco optimization virtual machine if present.
-	"""
-	return False
-
 def select_row(treeview, column=0):
 	"""
 	Select a row in a treeview if any.
@@ -535,29 +507,9 @@ def disconnect_signal(signal_id, instance):
 	@type instance: A GObject object.
 	"""
 	try:
-		from operator import truth
-		if truth(signal_id) and truth(instance.handler_is_connected(signal_id)):
-			instance.disconnect(signal_id)
+		if signal_id and instance.handler_is_connected(signal_id): instance.disconnect(signal_id)
 	except AttributeError:
-		pass
-	return
-
-def delete_attributes(instance):
-	"""
-	Delete "writable" attributes of an object.
-
-	@param instance: An object to delete.
-	@type instance: A Python object.
-	"""
-	return
-
-def delete_list(sequence):
-	"""
-	Delete a list and its content
-	"""
-	from operator import truth
-	if truth(sequence):
-		[sequence.remove(x) for x in sequence]
+		print "Disconnect Signal error: ", instance
 	return
 
 def init_gnome():
@@ -576,6 +528,8 @@ def init_gnome():
 
 try:
 	from psyco import bind
-	bind(response)
+	bind(generate_random_number)
+	bind(calculate_completion_window_position)
+	bind(disconnect_signal)
 except ImportError:
 	pass
