@@ -53,7 +53,6 @@ class BracketManager(object):
 		self.__signal_id_1 = editor.textview.connect("key-press-event", self.__key_press_event_cb)
 		self.__signal_id_2 = editor.connect("cursor-moved", self.__cursor_moved_cb)
 		self.__signal_id_3 = editor.connect("loaded-document", self.__loaded_document_cb)
-		self.__signal_id_4 = editor.textview.connect_after("key-press-event", self.__key_press_event_after_cb)
 
 	def __init_attributes(self, editor):
 		"""
@@ -173,24 +172,24 @@ class BracketManager(object):
 		@param close_keyval: A value representing the closing character.
 		@type close_keyval: An Integer object.
 		"""
+		self.__editor.block_response()
 		textbuffer = self.__editor.textbuffer
 		from gtk.gdk import keyval_to_unicode
 		utf8_open_character = unichr(keyval_to_unicode(open_keyval)).encode("utf-8")
 		utf8_closing_character = unichr(keyval_to_unicode(close_keyval)).encode("utf-8")
-		from SCRIBES.cursor import get_cursor_iterator
-		cursor_position = get_cursor_iterator(textbuffer)
+		cursor_position = self.__editor.get_cursor_iterator()
 		begin_mark = textbuffer.create_mark(None, cursor_position, True)
 		textbuffer.begin_user_action()
 		textbuffer.insert_at_cursor(utf8_open_character+utf8_closing_character)
 		textbuffer.end_user_action()
-		from SCRIBES.cursor import get_cursor_iterator
-		cursor_position = get_cursor_iterator(textbuffer)
+		cursor_position = self.__editor.get_cursor_iterator()
 		end_mark = textbuffer.create_mark(None, cursor_position, False)
 		cursor_position.backward_char()
 		textbuffer.place_cursor(cursor_position)
 		self.__monitor_list.append((close_keyval, (begin_mark, end_mark)))
 		from i18n import msg0001
 		self.__editor.feedback.update_status_message(msg0001, "succeed")
+		self.__editor.unblock_response()
 		return
 
 	def __enclose_selection(self, keyval):
@@ -256,6 +255,7 @@ class BracketManager(object):
 		@param close_keyval: An integer representing a close pair character.
 		@type close_keyval: An Integer object.
 		"""
+		self.__editor.block_response()
 		textbuffer = self.__editor.textbuffer
 		from gtk.gdk import keyval_to_unicode
 		utf8_open_character = unichr(keyval_to_unicode(open_keyval)).encode("utf-8")
@@ -269,6 +269,7 @@ class BracketManager(object):
 		textbuffer.end_user_action()
 		from i18n import msg0002
 		self.__editor.feedback.update_status_message(msg0002, "succeed")
+		self.__editor.unblock_response()
 		return
 
 	def __move_cursor_out_of_bracket_region(self):
@@ -282,8 +283,7 @@ class BracketManager(object):
 		end_mark = self.__monitor_list[-1][1][1]
 		iterator = textbuffer.get_iter_at_mark(end_mark)
 		textbuffer.place_cursor(iterator)
-		from SCRIBES.cursor import move_view_to_cursor
-		move_view_to_cursor(self.__editor.textview)
+		self.__editor.move_view_to_cursor()
 		return
 
 	def __stop_monitoring(self):
@@ -327,7 +327,9 @@ class BracketManager(object):
 		if ne(begin.get_char(), character): return False
 		begin.backward_char()
 		textbuffer.begin_user_action()
+		self.__editor.block_response()
 		textbuffer.delete(begin, end)
+		self.__editor.unblock_response()
 		textbuffer.end_user_action()
 		from i18n import msg0003
 		self.__editor.feedback.update_status_message(msg0003, "succeed")
@@ -360,7 +362,9 @@ class BracketManager(object):
 		end_iterator = self.__editor.get_cursor_position()
 		start_iterator = end_iterator.copy()
 		start_iterator.backward_char()
+		self.__editor.block_response()
 		self.__editor.textbuffer.delete(start_iterator, end_iterator)
+		self.__editor.unblock_response()
 		return
 
 	def __can_insert_apostrophe(self):
@@ -377,8 +381,7 @@ class BracketManager(object):
 		@return: True to insert automatically insert apostrophe.
 		@rtype: A Boolean object.
 		"""
-		from SCRIBES.cursor import get_cursor_iterator
-		iterator = get_cursor_iterator(self.__editor.textbuffer)
+		iterator = self.__editor.get_cursor_iterator()
 		from operator import truth
 		if truth(iterator.starts_line()): return True
 		iterator.backward_char()
@@ -396,7 +399,9 @@ class BracketManager(object):
 		from gtk import keysyms
 		from gtk.gdk import keyval_to_unicode
 		utf8_apostrophe_character = unichr(keyval_to_unicode(keysyms.apostrophe)).encode("utf-8")
+		self.__editor.block_response()
 		self.__editor.textbuffer.insert_at_cursor(utf8_apostrophe_character)
+		self.__editor.unblock_response()
 		return
 
 	def __check_mimetype(self):
@@ -432,6 +437,8 @@ class BracketManager(object):
 		"""
 		try:
 			from psyco import bind
+			bind(self.__key_press_event_cb)
+			bind(self.__cursor_moved_cb)
 			bind(self.__insert_pair_characters)
 			bind(self.__insert_closing_pair_character)
 			bind(self.__insert_enclosed_selection)
@@ -454,12 +461,9 @@ class BracketManager(object):
 		@param self: Reference to the BracketManager instance.
 		@type self: A BracketManager object.
 		"""
-		from SCRIBES.utils import delete_attributes, disconnect_signal
-		disconnect_signal(self.__signal_id_1, self.__editor.textview)
-		disconnect_signal(self.__signal_id_2, self.__editor)
-		disconnect_signal(self.__signal_id_3, self.__editor)
-		disconnect_signal(self.__signal_id_4, self.__editor.textview)
-		delete_attributes(self)
+		self.__editor.disconnect_signal(self.__signal_id_1, self.__editor.textview)
+		self.__editor.disconnect_signal(self.__signal_id_2, self.__editor)
+		self.__editor.disconnect_signal(self.__signal_id_3, self.__editor)
 		self = None
 		del self
 		return
@@ -517,15 +521,6 @@ class BracketManager(object):
 			return True
 		return False
 
-	def __key_press_event_after_cb(self, *args):
-		from gobject import idle_add
-		idle_add(self.__response)
-		return False
-
-	def __response(self):
-		self.__editor.response()
-		return False
-
 	def __cursor_moved_cb(self, editor):
 		"""
 		Handles callback when the "cursor-moved" signal is emitted.
@@ -548,8 +543,7 @@ class BracketManager(object):
 		end_mark = self.__monitor_list[-1][1][1]
 		begin = textbuffer.get_iter_at_mark(begin_mark)
 		end = textbuffer.get_iter_at_mark(end_mark)
-		from SCRIBES.cursor import get_cursor_iterator
-		cursor_position = get_cursor_iterator(textbuffer)
+		cursor_position = self.__editor.get_cursor_iterator()
 		if truth(cursor_position.equal(begin)) or truth(cursor_position.equal(end)):
 			self.__stop_monitoring()
 		elif not_(cursor_position.in_range(begin, end)):
