@@ -18,9 +18,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-from gettext import gettext
-_ = gettext
+from gettext import gettext as _
 msg0001 = _("Pair character completion occurred")
 msg0002 = _("Enclosed selected text")
 msg0003 = _("Removed pair character completion")
-
