@@ -18,8 +18,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-from gettext import gettext
-_ = gettext
+from gettext import gettext as _
 msg0001 = _("Open Document")
 msg0002 = _("Type URI for loading")
 msg0003 = _("Enter the location (URI) of the file you _would like to open:")
