@@ -52,6 +52,7 @@ class TemplateProcessor(object):
 		@param template: A string representing a template.
 		@type template: A String object.
 		"""
+		template = self.__replace_tabs(editor,template)
 		self.__init_attributes(manager, editor, template)
 		from utils import insert_string
 		editor.textbuffer.begin_user_action()
@@ -70,7 +71,6 @@ class TemplateProcessor(object):
 											self.__insert_text_after_cb)
 			from i18n import msg0001
 			self.__status_id = self.__editor.feedback.set_modal_message(msg0001, "info")
-
 		else:
 			editor.textbuffer.end_user_action()
 			idle_add(self.__destroy_cb, manager)
@@ -209,8 +209,7 @@ class TemplateProcessor(object):
 		else:
 			iterator = self.__editor.textbuffer.get_iter_at_mark(begin_mark)
 			self.__editor.textbuffer.place_cursor(iterator)
-		from SCRIBES.cursor import move_view_to_cursor
-		move_view_to_cursor(self.__editor.textview)
+		self.__editor.move_view_to_cursor()
 		from i18n import msg0004
 		self.__editor.feedback.update_status_message(msg0004, "yes")
 		return
@@ -435,6 +434,21 @@ class TemplateProcessor(object):
 		self.__editor.textbuffer.handler_unblock(self.__signal_id_4)
 		return
 
+	def __replace_tabs(self, editor, template):
+		"""
+		Contribution by rockalite
+		"""
+		client = editor.gconf_client
+		use_tabs = True
+		if client.get("/apps/scribes/use_tabs"):
+			use_tabs = client.get_bool("/apps/scribes/use_tabs")
+		if not use_tabs:
+			tab_width = 4
+			if client.get("/apps/scribes/tab"):
+				tab_width = client.get_int("/apps/scribes/tab")
+			return template.replace('\t', ' ' * tab_width)
+		return template
+
 ########################################################################
 #
 #						Tags for Placeholders
@@ -561,13 +575,16 @@ class TemplateProcessor(object):
 		@return: True to propagate signals to parent widgets.
 		@type: A Boolean Object.
 		"""
+		self.__editor.block_response()
 		from operator import ne, contains
 		if ne(self.__index, self.__last_index):
 			# Ignore every other index other than the last one.
+			self.__editor.unblock_response()
 			return False
 		begin_mark, end_mark, value = self.__placeholder_dictionary[self.__index]
 		if contains(self.__mirror_dictionary.keys(), (begin_mark, end_mark)):
 			# Ignore mirrors.
+			self.__editor.unblock_response()
 			return False
 		# Exit template mode when the user types over the last placeholder.
 		if begin_mark and end_mark and value:
@@ -579,6 +596,7 @@ class TemplateProcessor(object):
 			iterator = self.__editor.textbuffer.get_iter_at_mark(begin_mark)
 			if iterator.equal(iterator):
 				self.__destroy_cb(self.__manager)
+		self.__editor.unblock_response()
 		return False
 
 	def __get_modified_placeholder(self):
@@ -644,20 +662,22 @@ class TemplateProcessor(object):
 		from operator import not_
 		if not_(placeholder): return False
 		# Tag placeholder that is being modified.
+		self.__editor.block_response()
 		begin_position = self.__editor.textbuffer.get_iter_at_mark(placeholder[0])
 		end_position = self.__editor.textbuffer.get_iter_at_mark(placeholder[1])
 		self.__editor.textbuffer.apply_tag(self.__modification_highlight_tag,
 											begin_position, end_position)
 		self.__update_index(placeholder[0], placeholder[1])
+		self.__editor.unblock_response()
 		return False
 
 	def __destroy_cb(self, manager):
-		from SCRIBES.utils import delete_attributes, disconnect_signal
+		self.__editor.block_response()
 		self.__manager.emit("template-destroyed", self)
-		disconnect_signal(self.__signal_id_1, manager)
-		disconnect_signal(self.__signal_id_2, self.__editor)
-		disconnect_signal(self.__signal_id_3, self.__editor.textbuffer)
-		disconnect_signal(self.__signal_id_4, self.__editor.textbuffer)
+		self.__editor.disconnect_signal(self.__signal_id_1, manager)
+		self.__editor.disconnect_signal(self.__signal_id_2, self.__editor)
+		self.__editor.disconnect_signal(self.__signal_id_3, self.__editor.textbuffer)
+		self.__editor.disconnect_signal(self.__signal_id_4, self.__editor.textbuffer)
 		# Remove all tags associated with this template object.
 		begin_position = self.__editor.textbuffer.get_iter_at_mark(self.__start_template_mark)
 		end_position = self.__editor.textbuffer.get_iter_at_mark(self.__end_template_mark)
@@ -682,7 +702,7 @@ class TemplateProcessor(object):
 		self.__editor.feedback.unset_modal_message(self.__status_id)
 		from i18n import msg0002
 		self.__editor.feedback.update_status_message(msg0002, "yes")
-		delete_attributes(self)
+		self.__editor.unblock_response()
 		self = None
 		del self
 		return False
